#ifndef NT2_INCLUDE_FUNCTIONS_CSCD_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_CSCD_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/cscd.hpp>

#endif
